# Changelog

## [v0.4.1](https://github.com/jug-dev/hordelib/tree/v0.4.1) (2023-04-10)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/v0.4.0...v0.4.1)

**Merged pull requests:**

- test: fix test with red border around it [\#58](https://github.com/jug-dev/hordelib/pull/58) ([jug-dev](https://github.com/jug-dev))
- build: activate build results website [\#57](https://github.com/jug-dev/hordelib/pull/57) ([jug-dev](https://github.com/jug-dev))
- build: make a webpage of test result images [\#55](https://github.com/jug-dev/hordelib/pull/55) ([jug-dev](https://github.com/jug-dev))
- test: fix black 64x64 image tests [\#54](https://github.com/jug-dev/hordelib/pull/54) ([jug-dev](https://github.com/jug-dev))
- ref: Make use of the ControlNet ModelManager [\#53](https://github.com/jug-dev/hordelib/pull/53) ([db0](https://github.com/db0))

## [v0.4.0](https://github.com/jug-dev/hordelib/tree/v0.4.0) (2023-04-10)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/v0.3.1...v0.4.0)

**Closed issues:**

- Add support for Depth2Img [\#37](https://github.com/jug-dev/hordelib/issues/37)
- Add face fixers [\#33](https://github.com/jug-dev/hordelib/issues/33)
- Add support for controlnet [\#5](https://github.com/jug-dev/hordelib/issues/5)

**Merged pull requests:**

- feat: add face fixing support [\#50](https://github.com/jug-dev/hordelib/pull/50) ([jug-dev](https://github.com/jug-dev))

## [v0.3.1](https://github.com/jug-dev/hordelib/tree/v0.3.1) (2023-04-10)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/v0.3.0...v0.3.1)

**Merged pull requests:**

- test: change all tests to webp [\#49](https://github.com/jug-dev/hordelib/pull/49) ([jug-dev](https://github.com/jug-dev))

## [v0.3.0](https://github.com/jug-dev/hordelib/tree/v0.3.0) (2023-04-10)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/v0.2.2...v0.3.0)

**Closed issues:**

- Add support for inpainting models [\#36](https://github.com/jug-dev/hordelib/issues/36)

**Merged pull requests:**

- feat: add controlnet support [\#46](https://github.com/jug-dev/hordelib/pull/46) ([jug-dev](https://github.com/jug-dev))

## [v0.2.2](https://github.com/jug-dev/hordelib/tree/v0.2.2) (2023-04-09)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/v0.2.1...v0.2.2)

**Merged pull requests:**

- ci: inpainting tests [\#47](https://github.com/jug-dev/hordelib/pull/47) ([db0](https://github.com/db0))

## [v0.2.1](https://github.com/jug-dev/hordelib/tree/v0.2.1) (2023-04-09)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/v0.2.0...v0.2.1)

**Merged pull requests:**

- build: change how custom nodes are loaded into comfyui [\#44](https://github.com/jug-dev/hordelib/pull/44) ([jug-dev](https://github.com/jug-dev))

## [v0.2.0](https://github.com/jug-dev/hordelib/tree/v0.2.0) (2023-04-09)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/v0.1.0...v0.2.0)

**Closed issues:**

- Add img2img support for hires fix pipeline [\#31](https://github.com/jug-dev/hordelib/issues/31)
- Add support for image to image [\#6](https://github.com/jug-dev/hordelib/issues/6)
- Add support for hires fix [\#4](https://github.com/jug-dev/hordelib/issues/4)

**Merged pull requests:**

- ci: Disable pypi publish [\#45](https://github.com/jug-dev/hordelib/pull/45) ([db0](https://github.com/db0))
- docs: readme updates. [\#43](https://github.com/jug-dev/hordelib/pull/43) ([jug-dev](https://github.com/jug-dev))
- docs: readme updates. [\#42](https://github.com/jug-dev/hordelib/pull/42) ([jug-dev](https://github.com/jug-dev))
- feat: Re-adds diffusers model manager functionality [\#41](https://github.com/jug-dev/hordelib/pull/41) ([tazlin](https://github.com/tazlin))
- test: add diffusers inpainting run example [\#40](https://github.com/jug-dev/hordelib/pull/40) ([jug-dev](https://github.com/jug-dev))
- docs: update readme [\#39](https://github.com/jug-dev/hordelib/pull/39) ([jug-dev](https://github.com/jug-dev))
- docs: update changelog [\#38](https://github.com/jug-dev/hordelib/pull/38) ([jug-dev](https://github.com/jug-dev))
- We do some light refactoring... [\#34](https://github.com/jug-dev/hordelib/pull/34) ([db0](https://github.com/db0))
- Optimized tests [\#32](https://github.com/jug-dev/hordelib/pull/32) ([db0](https://github.com/db0))
- ci: Reintroduce black, apply black  [\#30](https://github.com/jug-dev/hordelib/pull/30) ([tazlin](https://github.com/tazlin))
- Post\_processors [\#27](https://github.com/jug-dev/hordelib/pull/27) ([db0](https://github.com/db0))

## [v0.1.0](https://github.com/jug-dev/hordelib/tree/v0.1.0) (2023-04-06)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/v0.0.10...v0.1.0)

**Closed issues:**

- Add support for clip skip [\#3](https://github.com/jug-dev/hordelib/issues/3)

**Merged pull requests:**

- fix: Duplicate lines [\#25](https://github.com/jug-dev/hordelib/pull/25) ([tazlin](https://github.com/tazlin))
- feat: Adds a github action when pushing to main that will generate a new release and an automatic changelog [\#24](https://github.com/jug-dev/hordelib/pull/24) ([jug-dev](https://github.com/jug-dev))
- fix: References to `horde_model_manager`, more docs [\#23](https://github.com/jug-dev/hordelib/pull/23) ([tazlin](https://github.com/tazlin))
- docs: Update LICENSE [\#20](https://github.com/jug-dev/hordelib/pull/20) ([tazlin](https://github.com/tazlin))
- refactor: ModelManager improvements, test adjustments [\#19](https://github.com/jug-dev/hordelib/pull/19) ([tazlin](https://github.com/tazlin))
- validate\_model should return results [\#18](https://github.com/jug-dev/hordelib/pull/18) ([db0](https://github.com/db0))
- refactor: 'ModelManager' rework, added 'WorkerSettings' [\#17](https://github.com/jug-dev/hordelib/pull/17) ([tazlin](https://github.com/tazlin))
- refactor: Test tweaks, type hint fixes [\#16](https://github.com/jug-dev/hordelib/pull/16) ([tazlin](https://github.com/tazlin))
- refactor: Type hints, refactoring, preemptive checks [\#15](https://github.com/jug-dev/hordelib/pull/15) ([tazlin](https://github.com/tazlin))

## [v0.0.10](https://github.com/jug-dev/hordelib/tree/v0.0.10) (2023-04-03)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/v0.0.9...v0.0.10)

**Merged pull requests:**

- fix: test\_horde.py syntax error [\#14](https://github.com/jug-dev/hordelib/pull/14) ([tazlin](https://github.com/tazlin))
- fix: Compat fixes for tests from pr \#11 [\#12](https://github.com/jug-dev/hordelib/pull/12) ([tazlin](https://github.com/tazlin))
- Clip merge - with formatting [\#11](https://github.com/jug-dev/hordelib/pull/11) ([tazlin](https://github.com/tazlin))
- Adds support for using a Model Manager  [\#8](https://github.com/jug-dev/hordelib/pull/8) ([db0](https://github.com/db0))

## [v0.0.9](https://github.com/jug-dev/hordelib/tree/v0.0.9) (2023-04-03)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/v0.0.8...v0.0.9)

**Closed issues:**

- How do we run unit tests on github that need a 2GB model checkpoint? [\#9](https://github.com/jug-dev/hordelib/issues/9)

## [v0.0.8](https://github.com/jug-dev/hordelib/tree/v0.0.8) (2023-04-02)

[Full Changelog](https://github.com/jug-dev/hordelib/compare/e3eae1c452e0f3145af3b8b62c14c377b3136f7b...v0.0.8)

**Closed issues:**

- Integrate the SD hires fix pipeline example [\#1](https://github.com/jug-dev/hordelib/issues/1)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
